"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.releaseSelectorState = exports.getSelectorState = exports.setSelectorState = void 0;

var _lodash = _interopRequireDefault(require("lodash.isequal"));

var _getHash = _interopRequireDefault(require("../internal/get-hash"));

var initialStateManager = new Map();

var getSelectorKey = function getSelectorKey(selector) {
  if (typeof selector === 'string') {
    return selector;
  }

  var _selector$query = selector.query,
      name = _selector$query.name,
      resolver = _selector$query.resolver,
      args = _selector$query.args;
  return (0, _getHash["default"])(name) + ":" + (0, _getHash["default"])(resolver) + ":" + (0, _getHash["default"])(args);
};

var setSelectorState = function setSelectorState(selector, state) {
  var key = getSelectorKey(selector);
  var entry = initialStateManager.get(key);

  if (entry != null) {
    if (!(0, _lodash["default"])(entry.state, state)) {
      throw Error("initial states conflict, check useReduxReadModel hook calls");
    }

    entry.references++;
  } else {
    initialStateManager.set(getSelectorKey(selector), {
      references: 1,
      state: state
    });
  }
};

exports.setSelectorState = setSelectorState;

var getSelectorState = function getSelectorState(selector) {
  var entry = initialStateManager.get(getSelectorKey(selector));

  if (entry != null) {
    return entry.state;
  }

  return null;
};

exports.getSelectorState = getSelectorState;

var releaseSelectorState = function releaseSelectorState(selector) {
  var entry = initialStateManager.get(getSelectorKey(selector));

  if (entry != null) {
    entry.references--;

    if (entry.references === 0) {
      initialStateManager["delete"](getSelectorKey(selector));
    }
  }
};

exports.releaseSelectorState = releaseSelectorState;
//# sourceMappingURL=initial-state-manager.js.map